@@ -42,7 +42,6 @@ def supertrend(df,atr_periodsuper,factorsuper):
     if super1==True and super3==False and super4==False and super5==False and super6==False:
         seniales="Compra"
 
-
     elif super1==True or super2==True or super3==True or super4==True or super5==True or super6==True or super7==True or super8==True or super9==True or super10==True:
         seniales="EN COMPRA"
 
@@ -70,7 +69,7 @@ def atr(df,atr_period,cual):
     rangoya=df['atr_14'].iloc[-1]
     return rangoya
 def bandasbb(df,periodobb,deviastandar):
-    df['media'] = df['close'].rolling(periodobb).mean()
+    df['media'] = df['close'].rolling(window=periodobb).mean()
     m_avg = df['close'].rolling(window=periodobb).mean()
     m_std = df['close'].rolling(window=periodobb).std(ddof=0)
     df['upper_BB'] = m_avg.astype(float)  + deviastandar * m_std.astype(float)
@@ -153,11 +152,14 @@ def sopoyresi(df,tipo):
     open=df['open'].iloc[-1]
 
     if tipo=="tradicional":
+
+
         pp = ((alto + bajo + cierre))/3
         re1 = (pp *2) - bajo
         so1 = (pp *2) - alto
         re2 = pp  + (alto - bajo)
         so2 = pp - (alto - bajo)
+
     if tipo=="classic":
         pp = ((alto + bajo + cierre))/3
         pivot_range = alto - bajo
@@ -317,7 +319,7 @@ def LazyBear(df,length,mult,length_KC,mult_KC,crucescompra,crucesventa,usarvola)
     
 
 
-    lazi=""
+    lazi="ninguna"
     if enter_long==True:
         lazi="comprar"
     
@@ -352,20 +354,9 @@ def dmi(df,period,perioddi):
     adxx=df['ADX'].iloc[-1]
     return adxx,masx,menosx
 def aroon(df,periodoaron):
-    df["25d High"] = df["high"].rolling(min_periods=periodoaron, window=periodoaron, center=False).max()
-    df["25d Low"] = df["low"].rolling(min_periods=periodoaron, window=periodoaron, center=False).min()
-    ind = range(0,len(df))
-    indexlist = list(ind)
-    df.index = indexlist
-    recent_high = df.iloc[-1]["25d High"]
-    ind_of_high = np.where(df["25d High"]==recent_high)[0][0] 
-    recent_low = df.iloc[-1]["25d Low"]
-    ind_of_low = np.where(df["25d Low"]==recent_low)[0][0]
-    days_since_high = (len(df) - 1) - ind_of_high
-    days_since_low = (len(df) - 1) - ind_of_low
-    aroon_up = float(((periodoaron - days_since_high)/periodoaron) * 100)
-    aroon_down = float(((periodoaron - days_since_low)/periodoaron) * 100)
-    return aroon_up,aroon_down
+    df['up'] = 100 * df['high'].rolling(periodoaron + 1).apply(lambda x: x.argmax()) / periodoaron
+    df['dn'] = 100 * df['low'].rolling(periodoaron + 1).apply(lambda x: x.argmin()) / periodoaron
+    return df['up'].iloc[-1], df['dn'].iloc[-1]
 def chandelier(df,atr_period,atrmulti):
     df['range'] = df['high'].astype(float) - df['low'].astype(float)
     df['Avg TR'] = df['range'].rolling(atr_period).mean()
@@ -374,6 +365,8 @@ def chandelier(df,atr_period,atrmulti):
     rolling_low = rangoya["low"][-atr_period:].max()
     comprach = rolling_high - df.iloc[-1]["Avg TR"] * atrmulti
     ventach = rolling_low - df.iloc[-1]["Avg TR"] * atrmulti
+
+
     return comprach,ventach
 def rvi(df, longitud):
     open=df['open']
